==> entity_repeat-1.0.0.tar.gz: entity_repeat/src/EventSubscriber/EntityRepeatEventSubscriber.php <==
<?php

namespace Drupal\entity_repeat\EventSubscriber;


/**
 * Event subscribers for Recurring Date Field.
 *
 */
class EntityRepeatEventSubscriber implements \Symfony\Component\EventDispatcher\EventSubscriberInterface {

  /**
   * Dispatched after an entity containing a date recur field is saved.
   *
   * @param \Drupal\date_recur\Event\DateRecurValueEvent $event
   *   The date recur value event.
   *
   * @see \Drupal\date_recur\Event\DateRecurEvents::FIELD_VALUE_SAVE
   *   Event name.
   * @see \Drupal\date_recur\Plugin\Field\FieldType\DateRecurFieldItemList::postSave
   *   Dispatched by.
   */
  public function onSave(\Drupal\date_recur\Event\DateRecurValueEvent $event) {
    $field = $event->getField();

    // Get the entity the recur field is on.
    $entity = $field->getEntity();

    // Only generate entities if recurring has been set.
    if (empty($entity->data['entity_repeat_enabled'])) {
      return;
    }

    // Un-set to avoid infinite loop.
    unset($entity->data['entity_repeat_enabled']);

    $helper = $field->get(0)->getHelper();

    // Get date occurrences.
    $dates = $helper->getOccurrences();

    // Generate the entities.
    _entity_repeat_generate_entities($entity, $helper, $dates);

  }

  /**
   * Dispatched when an entity containing date recur fields is almost deleted.
   *
   * @param \Drupal\date_recur\Event\DateRecurValueEvent $event
   *   The date recur value event.
   *
   * @see \Drupal\date_recur\Event\DateRecurEvents::FIELD_ENTITY_DELETE
   *   Event name.
   * @see \Drupal\date_recur\Plugin\Field\FieldType\DateRecurFieldItemList::delete
   *   Dispatched by.
   * @see \Drupal\date_recur\DateRecurOccurrences::onEntityDelete
   *   Live example.
   */
  public function onEntityDelete(\Drupal\date_recur\Event\DateRecurValueEvent $event): void {}

  /**
   * Dispatched when an entity revision is deleted.
   *
   * @param \Drupal\date_recur\Event\DateRecurValueEvent $event
   *   The date recur value event.
   *
   * @see \Drupal\date_recur\Event\DateRecurEvents::FIELD_REVISION_DELETE
   *   Event name.
   * @see \Drupal\date_recur\Plugin\Field\FieldType\DateRecurFieldItemList::deleteRevision
   *   Dispatched by.
   * @see \Drupal\date_recur\DateRecurOccurrences::onEntityRevisionDelete
   *   Live example.
   */
  public function onEntityRevisionDelete(\Drupal\date_recur\Event\DateRecurValueEvent $event): void {}

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    return [
      \Drupal\date_recur\Event\DateRecurEvents::FIELD_VALUE_SAVE => ['onSave'],
      \Drupal\date_recur\Event\DateRecurEvents::FIELD_ENTITY_DELETE => ['onEntityDelete'],
      \Drupal\date_recur\Event\DateRecurEvents::FIELD_REVISION_DELETE => ['onEntityRevisionDelete'],
    ];
  }

}

==> entity_repeat-1.0.1.tar.gz: entity_repeat/src/EventSubscriber/EntityRepeatEventSubscriber.php <==
<?php

namespace Drupal\entity_repeat\EventSubscriber;

use Drupal\date_recur\Event\DateRecurEvents;
use Drupal\date_recur\Event\DateRecurValueEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Event subscribers for Recurring Date Field.
 */
class EntityRepeatEventSubscriber implements EventSubscriberInterface {

  /**
   * Dispatched after an entity containing a date recur field is saved.
   *
   * @param \Drupal\date_recur\Event\DateRecurValueEvent $event
   *   The date recur value event.
   *
   * @see \Drupal\date_recur\Event\DateRecurEvents::FIELD_VALUE_SAVE
   *   Event name.
   * @see \Drupal\date_recur\Plugin\Field\FieldType\DateRecurFieldItemList::postSave
   *   Dispatched by.
   */
  public function onSave(DateRecurValueEvent $event) {
    $field = $event->getField();

    // Get the entity the recur field is on.
    $entity = $field->getEntity();

    // Only generate entities if recurring has been set.
    if (empty($entity->data['entity_repeat_enabled'])) {
      return;
    }

    // Un-set to avoid infinite loop.
    unset($entity->data['entity_repeat_enabled']);

    $helper = $field->get(0)->getHelper();

    // Get date occurrences.
    $dates = $helper->getOccurrences();

    // Generate the entities.
    _entity_repeat_generate_entities($entity, $helper, $dates);

  }

  /**
   * Dispatched when an entity containing date recur fields is almost deleted.
   *
   * @param \Drupal\date_recur\Event\DateRecurValueEvent $event
   *   The date recur value event.
   *
   * @see \Drupal\date_recur\Event\DateRecurEvents::FIELD_ENTITY_DELETE
   *   Event name.
   * @see \Drupal\date_recur\Plugin\Field\FieldType\DateRecurFieldItemList::delete
   *   Dispatched by.
   * @see \Drupal\date_recur\DateRecurOccurrences::onEntityDelete
   *   Live example.
   */
  public function onEntityDelete(DateRecurValueEvent $event): void {}

  /**
   * Dispatched when an entity revision is deleted.
   *
   * @param \Drupal\date_recur\Event\DateRecurValueEvent $event
   *   The date recur value event.
   *
   * @see \Drupal\date_recur\Event\DateRecurEvents::FIELD_REVISION_DELETE
   *   Event name.
   * @see \Drupal\date_recur\Plugin\Field\FieldType\DateRecurFieldItemList::deleteRevision
   *   Dispatched by.
   * @see \Drupal\date_recur\DateRecurOccurrences::onEntityRevisionDelete
   *   Live example.
   */
  public function onEntityRevisionDelete(DateRecurValueEvent $event): void {}

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    return [
      DateRecurEvents::FIELD_VALUE_SAVE => ['onSave'],
      DateRecurEvents::FIELD_ENTITY_DELETE => ['onEntityDelete'],
      DateRecurEvents::FIELD_REVISION_DELETE => ['onEntityRevisionDelete'],
    ];
  }

}
